# X509CertificateStatus

A X509CertificateStatus
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**not_before** | **datetime** | date/time for which certificate is valid | [optional] [readonly] 
**not_after** | **datetime** | date/time of certificate expiry | [optional] [readonly] 
**renewal_time** | **datetime** | date/time of certificate renewal | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


